import React, {useCallback, useRef, useState} from 'react';
import {
  Alert,
  Linking,
  Modal,
  Pressable,
  StyleSheet,
  Text,
  TouchableOpacity,
  View,
} from 'react-native';
import WebView from 'react-native-webview';
import {Colors} from 'react-native/Libraries/NewAppScreen';

let webViewRef;
const WebViewHeader = () => {
  return (
    <View style={styles.webViewHeader}>
      <Pressable onPress={() => webViewRef.current.goBack()}>
        <Text style={styles.headerButton}>{'< Back'}</Text>
      </Pressable>
      <Pressable onPress={() => webViewRef.current.goForward()}>
        <Text style={styles.headerButton}>{'Forw. >'}</Text>
      </Pressable>
    </View>
  );
};

const OpenURL = ({url, children, inWebView}) => {
  webViewRef = useRef();
  const [openWebView, setOpenWebView] = useState(false);
  const handlePress = useCallback(async () => {
    // Checking if the link is supported for links with custom URL scheme.
    const supported = await Linking.canOpenURL(url);
    if (inWebView) {
      setOpenWebView(true);
    } else if (supported) {
      // Opening the link with some app, if the URL scheme is "http" the web link should be opened
      // by some browser in the mobile
      await Linking.openURL(url);
    } else {
      Alert.alert(`Don't know how to open this URL: ${url}`);
    }
  }, [inWebView, url]);
  const onRequestClose = () => setOpenWebView(false);

  return openWebView ? (
    <Modal
      visible={openWebView}
      presentationStyle="pageSheet"
      animationType="slide"
      onRequestClose={onRequestClose}>
      <WebViewHeader />
      <WebView source={{uri: url}} ref={ref => (webViewRef.current = ref)} />
    </Modal>
  ) : (
    <TouchableOpacity onPress={handlePress}>
      <Text style={styles.linking}>{children}</Text>
    </TouchableOpacity>
  );
};

const styles = StyleSheet.create({
  linking: {
    color: 'deepskyblue',
    fontSize: 15,
  },
  headerButton: {
    fontSize: 20,
    fontWeight: '600',
    color: 'dodgerblue',
  },
  webViewHeader: {
    alignItems: 'center',
    justifyContent: 'space-between',
    backgroundColor: Colors.darker,
    flexDirection: 'row',
    height: 50,
    paddingHorizontal: 20,
  },
});

export default OpenURL;
