import React, {useEffect, useState} from 'react';
import {isEmpty} from 'lodash';
import {
  Animated,
  Button,
  Keyboard,
  KeyboardAvoidingView,
  StyleSheet,
  Text,
  TextInput,
  View,
} from 'react-native';
import {Colors} from 'react-native/Libraries/NewAppScreen';
import useColorScheme from 'react-native/Libraries/Utilities/useColorScheme';
import OpenURL from '../Components/OpenURL';

const dismissModalDefault = () => console.log('dismissed');

const PaymentScreen = React.memo(props => {
  const [number, setNumber] = useState('');
  const [isError, setIsError] = useState(false);
  const handleDismissScreen = () => {
    if (isNaN(number) || isEmpty(number)) {
      setIsError(true);
      return;
    }
    const message = {message: 'Payment Successful'};
    typeof props?.handlePassbackData === 'function'
      ? props.handlePassbackData(message)
      : props?.parentNavigation?.navigate?.('My Tickets', message);
    typeof props?.handleDismissScreen === 'function'
      ? props.handleDismissScreen()
      : dismissModalDefault();
  };
  const isDarkMode = useColorScheme() === 'dark';
  const backgroundStyle = {
    backgroundColor: isDarkMode ? Colors.darker : Colors.lighter,
  };
  const textStyle = {
    color: isDarkMode ? Colors.lighter : Colors.darker,
  };

  useEffect(() => {
    if (isNaN(number)) {
      setIsError(true);
    } else {
      setIsError(false);
    }
  }, [number]);

  useEffect(() => {});

  return (
    <Animated.ScrollView
      scrollEventThrottle={1}
      onScroll={Animated.event(
        [
          {
            nativeEvent: {
              contentOffset: {
                x: new Animated.Value(0),
                y: new Animated.Value(0),
              },
            },
          },
        ],
        {useNativeDriver: true},
      )}
      contentInsetAdjustmentBehavior="automatic"
      showsVerticalScrollIndicator={false}
      contentContainerStyle={styles.contentContainerStyle}
      style={backgroundStyle}>
      <KeyboardAvoidingView
        behavior="padding"
        style={[styles.keyboardAvoidingViewContainer, backgroundStyle]}>
        <Text style={[styles.appTitle, textStyle]}>
          {'Please provide your gPay number'}
        </Text>
        <TextInput
          keyboardType="phone-pad"
          maxLength={10}
          onChangeText={setNumber}
          onSubmitEditing={Keyboard.dismiss}
          placeholder="Mobile number"
          style={[styles.textInput, textStyle, isError && styles.borderRed]}
          value={number}
        />
        {isError ? (
          <Text style={styles.errorText}>{'Enter a valid mobile number'}</Text>
        ) : (
          <></>
        )}
        <Button title="Make Payment" onPress={handleDismissScreen} />
      </KeyboardAvoidingView>
      <View style={styles.linkingContainer}>
        <OpenURL
          url={'https://pay.google.com/intl/en_in/about/terms/'}
          inWebView>
          Terms and Conditions
        </OpenURL>
      </View>
    </Animated.ScrollView>
  );
});

const styles = StyleSheet.create({
  contentContainerStyle: {
    alignItems: 'center',
    justifyContent: 'center',
    height: '100%',
  },
  keyboardAvoidingViewContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#FFFFFF',
    width: '100%',
  },
  appTitle: {
    fontSize: 20,
    textAlign: 'center',
    margin: 10,
  },
  borderRed: {
    borderColor: 'red',
  },
  content: {
    textAlign: 'left',
    color: '#333333',
    marginBottom: 5,
  },
  errorText: {
    fontSize: 15,
    textAlign: 'center',
    marginBottom: 10,
    color: 'red',
  },
  linking: {
    color: 'dodgerblue',
    fontSize: 12,
  },
  linkingContainer: {
    justifyContent: 'flex-end',
    marginBottom: 50,
  },
  textInput: {
    height: 40,
    marginTop: 12,
    width: '60%',
    borderWidth: 1,
    padding: 10,
  },
});

export default PaymentScreen;
