import React, {useState} from 'react';
import {
  Animated,
  Button,
  Keyboard,
  KeyboardAvoidingView,
  StyleSheet,
  Text,
  TextInput,
} from 'react-native';
import {Colors} from 'react-native/Libraries/NewAppScreen';
import useColorScheme from 'react-native/Libraries/Utilities/useColorScheme';

const dismissModalDefault = () => console.log('dismissed');

const WelcomeScreen = React.memo(props => {
  const [message, setMessage] = useState('');
  const doubleTab = '\t\t';
  const journeys = props?.journeys?.map(journey => (
    <Text key={journey.id}>
      {`# ${journey.from}${doubleTab} -> ${doubleTab}${journey.to}\n`}
    </Text>
  ));

  const handleDismissScreen = () => {
    typeof props?.handlePassbackData === 'function'
      ? props.handlePassbackData({message})
      : props?.parentNavigation?.navigate?.('My Tickets', {message});
    typeof props?.handleDismissScreen === 'function'
      ? props.handleDismissScreen()
      : dismissModalDefault();
  };
  const handlePayment = () =>
    props.navigation.navigate('Payment', {mode: 'card'});
  const isDarkMode = useColorScheme() === 'dark';
  const backgroundStyle = {
    backgroundColor: isDarkMode ? Colors.darker : Colors.lighter,
  };
  const textStyle = {
    color: isDarkMode ? Colors.lighter : Colors.darker,
  };

  return (
    <Animated.ScrollView
      scrollEventThrottle={1}
      onScroll={Animated.event(
        [
          {
            nativeEvent: {
              contentOffset: {
                x: new Animated.Value(0),
                y: new Animated.Value(0),
              },
            },
          },
        ],
        {useNativeDriver: true},
      )}
      contentInsetAdjustmentBehavior="automatic"
      showsVerticalScrollIndicator={false}
      contentContainerStyle={styles.contentContainerStyle}
      style={backgroundStyle}>
      <KeyboardAvoidingView
        behavior="padding"
        style={[styles.keyboardAvoidingViewContainer, backgroundStyle]}>
        <Text style={[styles.appTitle, textStyle]}>Pay as you go</Text>
        <Text style={[styles.content, textStyle]}>Cash: £{props?.cash}</Text>
        <Text style={[styles.content, textStyle]}>{journeys}</Text>
        <TextInput
          keyboardType="ascii-capable"
          maxLength={31}
          onChangeText={setMessage}
          onSubmitEditing={Keyboard.dismiss}
          placeholder="Passback Message (Optional)"
          style={[styles.textInput, textStyle]}
          value={message}
        />
        <Button title="Proceed" onPress={handlePayment} />
        <Button title="Dismiss" color="red" onPress={handleDismissScreen} />
      </KeyboardAvoidingView>
    </Animated.ScrollView>
  );
});

const styles = StyleSheet.create({
  contentContainerStyle: {
    alignItems: 'center',
    justifyContent: 'center',
    height: '100%',
  },
  keyboardAvoidingViewContainer: {
    flex: 1,
    justifyContent: 'center',
    alignItems: 'center',
    backgroundColor: '#FFFFFF',
    width: '100%',
  },
  appTitle: {
    fontSize: 20,
    textAlign: 'center',
    margin: 10,
  },
  content: {
    textAlign: 'left',
    color: '#333333',
    marginBottom: 5,
  },
  textInput: {
    height: 40,
    margin: 12,
    width: '60%',
    borderWidth: 1,
    padding: 10,
  },
});

export default WelcomeScreen;
